@@ -28,12 +28,14 @@ use 5.006001;
 use warnings;
 use strict;
 
-our $VERSION = '2.13';
+our $VERSION = '2.14';
 
 BEGIN {
 	use POE;
-	if($POE::VERSION < '1.0001') {
-		die(__PACKAGE__." is only certified for POE version 1.0001 and up and you are running POE version " . $POE::VERSION . ". Check CPAN for an appropriate version of ".__PACKAGE__.".");
+	my $ver = $POE::VERSION;
+	$ver =~ s/_.+$//;
+	if($ver < '1.0001') {
+		die(__PACKAGE__." is only certified for POE version 1.0001 and up and you are running POE version " . $ver . ". Check CPAN for an appropriate version of ".__PACKAGE__.".");
 	}
 }
 
@@ -665,7 +667,9 @@ sub event_queue_dump {
 		} elsif ($type & POE::Kernel::ET_SELECT()) {
 			$type_str = 'File Activity';
 		} else {
-			if($POE::VERSION <= 0.27) {
+			my $ver = $POE::VERSION;
+			$ver =~ s/_.+$//;
+			if($ver <= 0.27) {
 				if($type & POE::Kernel::ET_USER()) {
 					$type_str = 'User';
 				} else {
